diff --git a/README.md b/README.md
index 59de28b..56ad01a 100644
--- a/README.md
+++ b/README.md
@@ -138,7 +138,7 @@ cd SillyTavern-extras
| `edge-tts` | [Microsoft Edge TTS client](https://github.com/rany2/edge-tts) | ✔️ Yes |
| `coqui-tts` | [Coqui TTS server](https://github.com/coqui-ai/TTS) | :x: No |
| `chromadb` | Infinity context server | :x: No |
-| `live2d` | Talking Head Sprites | :x: No |
+| `talkinghead` | Talking Head Sprites | :x: No |
## Additional options
| Flag | Description |
@@ -152,7 +152,7 @@ cd SillyTavern-extras
| `--mps` or `--m1` | Run the models on Apple Silicon. Only for M1 and M2 processors. |
| `--cuda` | Uses CUDA (GPU+VRAM) to run modules if it is available. Otherwise, falls back to using CPU. |
| `--cuda-device` | Specifies a CUDA device to use. Defaults to `cuda:0` (first available GPU). |
-| `--live2d-gpu` | Uses GPU for live2d (10x FPS increase in animation). |
+| `--talkinghead-gpu` | Uses GPU for talkinghead (10x FPS increase in animation). |
| `--coqui-gpu` | Uses GPU for coqui TTS (if available). |
| `--coqui-model` | If provided, downloads and preloads a coqui TTS model. Default: none.
Example: `tts_models/multilingual/multi-dataset/bark` |
| `--summarization-model` | Load a custom summarization model.
Expects a HuggingFace model ID.
Default: [Qiliang/bart-large-cnn-samsum-ChatGPT_v3](https://huggingface.co/Qiliang/bart-large-cnn-samsum-ChatGPT_v3) |
@@ -512,31 +512,31 @@ _progress (string, Optional): Show progress bar in terminal.
#### **Output**
MP3 audio file.
-### Loads a Live2D character by specifying the character's image URL.
-`GET /api/live2d/load`
+### Loads a talkinghead character by specifying the character's image URL.
+`GET /api/talkinghead/load`
#### **Parameters**
loadchar (string, required): The URL of the character's image. The URL should point to a PNG image.
{ "loadchar": "http://localhost:8000/characters/Aqua.png" }
#### **Example**
-'http://localhost:5100/api/live2d/load?loadchar=http://localhost:8000/characters/Aqua.png'
+'http://localhost:5100/api/talkinghead/load?loadchar=http://localhost:8000/characters/Aqua.png'
#### **Output**
'OK'
-### Animates the live2d sprite to start talking.
-`GET /api/live2d/start_talking`
+### Animates the talkinghead sprite to start talking.
+`GET /api/talkinghead/start_talking`
#### **Example**
-'http://localhost:5100/api/live2d/start_talking'
+'http://localhost:5100/api/talkinghead/start_talking'
#### **Output**
"started"
-### Animates the live2d sprite to stop talking.
-`GET /api/live2d/stop_talking`
+### Animates the talkinghead sprite to stop talking.
+`GET /api/talkinghead/stop_talking`
#### **Example**
-'http://localhost:5100/api/live2d/stop_talking'
+'http://localhost:5100/api/talkinghead/stop_talking'
#### **Output**
"stopped"
-### Outputs the animated live2d sprite.
-`GET /api/live2d/result_feed`
+### Outputs the animated talkinghead sprite.
+`GET /api/talkinghead/result_feed`
#### **Output**
Animated transparent image
diff --git a/live2d/Character Card Guide.png b/talkinghead/Character Card Guide.png
similarity index 100%
rename from live2d/Character Card Guide.png
rename to talkinghead/Character Card Guide.png
diff --git a/live2d/emotions/_defaults.json b/talkinghead/emotions/_defaults.json
similarity index 100%
rename from live2d/emotions/_defaults.json
rename to talkinghead/emotions/_defaults.json
diff --git a/live2d/emotions/admiration.json b/talkinghead/emotions/admiration.json
similarity index 100%
rename from live2d/emotions/admiration.json
rename to talkinghead/emotions/admiration.json
diff --git a/live2d/emotions/admiration.png b/talkinghead/emotions/admiration.png
similarity index 100%
rename from live2d/emotions/admiration.png
rename to talkinghead/emotions/admiration.png
diff --git a/live2d/emotions/amusement.json b/talkinghead/emotions/amusement.json
similarity index 100%
rename from live2d/emotions/amusement.json
rename to talkinghead/emotions/amusement.json
diff --git a/live2d/emotions/amusement.png b/talkinghead/emotions/amusement.png
similarity index 100%
rename from live2d/emotions/amusement.png
rename to talkinghead/emotions/amusement.png
diff --git a/live2d/emotions/anger.json b/talkinghead/emotions/anger.json
similarity index 100%
rename from live2d/emotions/anger.json
rename to talkinghead/emotions/anger.json
diff --git a/live2d/emotions/anger.png b/talkinghead/emotions/anger.png
similarity index 100%
rename from live2d/emotions/anger.png
rename to talkinghead/emotions/anger.png
diff --git a/live2d/emotions/annoyance.json b/talkinghead/emotions/annoyance.json
similarity index 100%
rename from live2d/emotions/annoyance.json
rename to talkinghead/emotions/annoyance.json
diff --git a/live2d/emotions/annoyance.png b/talkinghead/emotions/annoyance.png
similarity index 100%
rename from live2d/emotions/annoyance.png
rename to talkinghead/emotions/annoyance.png
diff --git a/live2d/emotions/approval.json b/talkinghead/emotions/approval.json
similarity index 100%
rename from live2d/emotions/approval.json
rename to talkinghead/emotions/approval.json
diff --git a/live2d/emotions/approval.png b/talkinghead/emotions/approval.png
similarity index 100%
rename from live2d/emotions/approval.png
rename to talkinghead/emotions/approval.png
diff --git a/live2d/emotions/caring.json b/talkinghead/emotions/caring.json
similarity index 100%
rename from live2d/emotions/caring.json
rename to talkinghead/emotions/caring.json
diff --git a/live2d/emotions/caring.png b/talkinghead/emotions/caring.png
similarity index 100%
rename from live2d/emotions/caring.png
rename to talkinghead/emotions/caring.png
diff --git a/live2d/emotions/confusion.json b/talkinghead/emotions/confusion.json
similarity index 100%
rename from live2d/emotions/confusion.json
rename to talkinghead/emotions/confusion.json
diff --git a/live2d/emotions/confusion.png b/talkinghead/emotions/confusion.png
similarity index 100%
rename from live2d/emotions/confusion.png
rename to talkinghead/emotions/confusion.png
diff --git a/live2d/emotions/curiosity.json b/talkinghead/emotions/curiosity.json
similarity index 100%
rename from live2d/emotions/curiosity.json
rename to talkinghead/emotions/curiosity.json
diff --git a/live2d/emotions/curiosity.png b/talkinghead/emotions/curiosity.png
similarity index 100%
rename from live2d/emotions/curiosity.png
rename to talkinghead/emotions/curiosity.png
diff --git a/live2d/emotions/desire.json b/talkinghead/emotions/desire.json
similarity index 100%
rename from live2d/emotions/desire.json
rename to talkinghead/emotions/desire.json
diff --git a/live2d/emotions/desire.png b/talkinghead/emotions/desire.png
similarity index 100%
rename from live2d/emotions/desire.png
rename to talkinghead/emotions/desire.png
diff --git a/live2d/emotions/disappointment.json b/talkinghead/emotions/disappointment.json
similarity index 100%
rename from live2d/emotions/disappointment.json
rename to talkinghead/emotions/disappointment.json
diff --git a/live2d/emotions/disappointment.png b/talkinghead/emotions/disappointment.png
similarity index 100%
rename from live2d/emotions/disappointment.png
rename to talkinghead/emotions/disappointment.png
diff --git a/live2d/emotions/disapproval.json b/talkinghead/emotions/disapproval.json
similarity index 100%
rename from live2d/emotions/disapproval.json
rename to talkinghead/emotions/disapproval.json
diff --git a/live2d/emotions/disapproval.png b/talkinghead/emotions/disapproval.png
similarity index 100%
rename from live2d/emotions/disapproval.png
rename to talkinghead/emotions/disapproval.png
diff --git a/live2d/emotions/disgust.json b/talkinghead/emotions/disgust.json
similarity index 100%
rename from live2d/emotions/disgust.json
rename to talkinghead/emotions/disgust.json
diff --git a/live2d/emotions/disgust.png b/talkinghead/emotions/disgust.png
similarity index 100%
rename from live2d/emotions/disgust.png
rename to talkinghead/emotions/disgust.png
diff --git a/live2d/emotions/embarrassment.json b/talkinghead/emotions/embarrassment.json
similarity index 100%
rename from live2d/emotions/embarrassment.json
rename to talkinghead/emotions/embarrassment.json
diff --git a/live2d/emotions/embarrassment.png b/talkinghead/emotions/embarrassment.png
similarity index 100%
rename from live2d/emotions/embarrassment.png
rename to talkinghead/emotions/embarrassment.png
diff --git a/live2d/emotions/excitement.json b/talkinghead/emotions/excitement.json
similarity index 100%
rename from live2d/emotions/excitement.json
rename to talkinghead/emotions/excitement.json
diff --git a/live2d/emotions/excitement.png b/talkinghead/emotions/excitement.png
similarity index 100%
rename from live2d/emotions/excitement.png
rename to talkinghead/emotions/excitement.png
diff --git a/live2d/emotions/fear.json b/talkinghead/emotions/fear.json
similarity index 100%
rename from live2d/emotions/fear.json
rename to talkinghead/emotions/fear.json
diff --git a/live2d/emotions/fear.png b/talkinghead/emotions/fear.png
similarity index 100%
rename from live2d/emotions/fear.png
rename to talkinghead/emotions/fear.png
diff --git a/live2d/emotions/gratitude.json b/talkinghead/emotions/gratitude.json
similarity index 100%
rename from live2d/emotions/gratitude.json
rename to talkinghead/emotions/gratitude.json
diff --git a/live2d/emotions/gratitude.png b/talkinghead/emotions/gratitude.png
similarity index 100%
rename from live2d/emotions/gratitude.png
rename to talkinghead/emotions/gratitude.png
diff --git a/live2d/emotions/grief.json b/talkinghead/emotions/grief.json
similarity index 100%
rename from live2d/emotions/grief.json
rename to talkinghead/emotions/grief.json
diff --git a/live2d/emotions/grief.png b/talkinghead/emotions/grief.png
similarity index 100%
rename from live2d/emotions/grief.png
rename to talkinghead/emotions/grief.png
diff --git a/live2d/emotions/joy.json b/talkinghead/emotions/joy.json
similarity index 100%
rename from live2d/emotions/joy.json
rename to talkinghead/emotions/joy.json
diff --git a/live2d/emotions/joy.png b/talkinghead/emotions/joy.png
similarity index 100%
rename from live2d/emotions/joy.png
rename to talkinghead/emotions/joy.png
diff --git a/live2d/emotions/love.json b/talkinghead/emotions/love.json
similarity index 100%
rename from live2d/emotions/love.json
rename to talkinghead/emotions/love.json
diff --git a/live2d/emotions/love.png b/talkinghead/emotions/love.png
similarity index 100%
rename from live2d/emotions/love.png
rename to talkinghead/emotions/love.png
diff --git a/live2d/emotions/nervousness.json b/talkinghead/emotions/nervousness.json
similarity index 100%
rename from live2d/emotions/nervousness.json
rename to talkinghead/emotions/nervousness.json
diff --git a/live2d/emotions/nervousness.png b/talkinghead/emotions/nervousness.png
similarity index 100%
rename from live2d/emotions/nervousness.png
rename to talkinghead/emotions/nervousness.png
diff --git a/live2d/emotions/neutral.json b/talkinghead/emotions/neutral.json
similarity index 100%
rename from live2d/emotions/neutral.json
rename to talkinghead/emotions/neutral.json
diff --git a/live2d/emotions/neutral.png b/talkinghead/emotions/neutral.png
similarity index 100%
rename from live2d/emotions/neutral.png
rename to talkinghead/emotions/neutral.png
diff --git a/live2d/emotions/optimism.json b/talkinghead/emotions/optimism.json
similarity index 100%
rename from live2d/emotions/optimism.json
rename to talkinghead/emotions/optimism.json
diff --git a/live2d/emotions/optimism.png b/talkinghead/emotions/optimism.png
similarity index 100%
rename from live2d/emotions/optimism.png
rename to talkinghead/emotions/optimism.png
diff --git a/live2d/emotions/pride.json b/talkinghead/emotions/pride.json
similarity index 100%
rename from live2d/emotions/pride.json
rename to talkinghead/emotions/pride.json
diff --git a/live2d/emotions/pride.png b/talkinghead/emotions/pride.png
similarity index 100%
rename from live2d/emotions/pride.png
rename to talkinghead/emotions/pride.png
diff --git a/live2d/emotions/realization.json b/talkinghead/emotions/realization.json
similarity index 100%
rename from live2d/emotions/realization.json
rename to talkinghead/emotions/realization.json
diff --git a/live2d/emotions/realization.png b/talkinghead/emotions/realization.png
similarity index 100%
rename from live2d/emotions/realization.png
rename to talkinghead/emotions/realization.png
diff --git a/live2d/emotions/relief.json b/talkinghead/emotions/relief.json
similarity index 100%
rename from live2d/emotions/relief.json
rename to talkinghead/emotions/relief.json
diff --git a/live2d/emotions/relief.png b/talkinghead/emotions/relief.png
similarity index 100%
rename from live2d/emotions/relief.png
rename to talkinghead/emotions/relief.png
diff --git a/live2d/emotions/remorse.json b/talkinghead/emotions/remorse.json
similarity index 100%
rename from live2d/emotions/remorse.json
rename to talkinghead/emotions/remorse.json
diff --git a/live2d/emotions/remorse.png b/talkinghead/emotions/remorse.png
similarity index 100%
rename from live2d/emotions/remorse.png
rename to talkinghead/emotions/remorse.png
diff --git a/live2d/emotions/sadness.json b/talkinghead/emotions/sadness.json
similarity index 100%
rename from live2d/emotions/sadness.json
rename to talkinghead/emotions/sadness.json
diff --git a/live2d/emotions/sadness.png b/talkinghead/emotions/sadness.png
similarity index 100%
rename from live2d/emotions/sadness.png
rename to talkinghead/emotions/sadness.png
diff --git a/live2d/emotions/surprise.json b/talkinghead/emotions/surprise.json
similarity index 100%
rename from live2d/emotions/surprise.json
rename to talkinghead/emotions/surprise.json
diff --git a/live2d/emotions/surprise.png b/talkinghead/emotions/surprise.png
similarity index 100%
rename from live2d/emotions/surprise.png
rename to talkinghead/emotions/surprise.png
diff --git a/live2d/tha3/__init__.py b/talkinghead/tha3/__init__.py
similarity index 100%
rename from live2d/tha3/__init__.py
rename to talkinghead/tha3/__init__.py
diff --git a/live2d/tha3/app/__init__.py b/talkinghead/tha3/app/__init__.py
similarity index 100%
rename from live2d/tha3/app/__init__.py
rename to talkinghead/tha3/app/__init__.py
diff --git a/live2d/tha3/app/app.py b/talkinghead/tha3/app/app.py
similarity index 99%
rename from live2d/tha3/app/app.py
rename to talkinghead/tha3/app/app.py
index a6e9691..e687c77 100644
--- a/live2d/tha3/app/app.py
+++ b/talkinghead/tha3/app/app.py
@@ -43,7 +43,7 @@ lasttranisitiondPose = "NotInit"
inMotion = False
fps = 0
current_pose = None
-storepath = os.path.join(os.getcwd(), "live2d", "emotions")
+storepath = os.path.join(os.getcwd(), "talkinghead", "emotions")
# Flask setup
app = Flask(__name__)
@@ -99,7 +99,7 @@ def result_feed():
time.sleep(0.1)
return Response(generate(), mimetype='multipart/x-mixed-replace; boundary=frame')
-def live2d_load_file(stream):
+def talkinghead_load_file(stream):
global global_source_image
global global_reload
global global_timer_paused
@@ -112,7 +112,7 @@ def live2d_load_file(stream):
global_reload = Image.open(BytesIO(img_data.getvalue())) # Set the global_reload to the copy of the image data
except Image.UnidentifiedImageError:
print(f"Could not load image from file, loading blank")
- full_path = os.path.join(os.getcwd(), "live2d\\tha3\\images\\inital.png")
+ full_path = os.path.join(os.getcwd(), "talkinghead\\tha3\\images\\inital.png")
MainFrame.load_image(None, full_path)
global_timer_paused = True
return 'OK'
@@ -140,7 +140,7 @@ def launch_gui(device, model):
main_frame.SetSize((750, 600))
#Lload default image (you can pass args.char if required)
- full_path = os.path.join(os.getcwd(), "live2d\\tha3\\images\\inital.png")
+ full_path = os.path.join(os.getcwd(), "talkinghead\\tha3\\images\\inital.png")
main_frame.load_image(None, full_path)
#main_frame.Show(True)
@@ -969,7 +969,7 @@ class MainFrame(wx.Frame):
if random.random() <= 0.01:
trimmed_fps = round(fps, 1)
- #print("Live2d FPS: {:.1f}".format(trimmed_fps))
+ #print("talkinghead FPS: {:.1f}".format(trimmed_fps))
#Store current pose to use as last pose on next loop
diff --git a/live2d/tha3/app/manual_poser.py b/talkinghead/tha3/app/manual_poser.py
similarity index 100%
rename from live2d/tha3/app/manual_poser.py
rename to talkinghead/tha3/app/manual_poser.py
diff --git a/live2d/tha3/compute/__init__.py b/talkinghead/tha3/compute/__init__.py
similarity index 100%
rename from live2d/tha3/compute/__init__.py
rename to talkinghead/tha3/compute/__init__.py
diff --git a/live2d/tha3/compute/cached_computation_func.py b/talkinghead/tha3/compute/cached_computation_func.py
similarity index 100%
rename from live2d/tha3/compute/cached_computation_func.py
rename to talkinghead/tha3/compute/cached_computation_func.py
diff --git a/live2d/tha3/compute/cached_computation_protocol.py b/talkinghead/tha3/compute/cached_computation_protocol.py
similarity index 100%
rename from live2d/tha3/compute/cached_computation_protocol.py
rename to talkinghead/tha3/compute/cached_computation_protocol.py
diff --git a/live2d/tha3/images/CC-BY-NC.txt b/talkinghead/tha3/images/CC-BY-NC.txt
similarity index 100%
rename from live2d/tha3/images/CC-BY-NC.txt
rename to talkinghead/tha3/images/CC-BY-NC.txt
diff --git a/live2d/tha3/images/README.md b/talkinghead/tha3/images/README.md
similarity index 100%
rename from live2d/tha3/images/README.md
rename to talkinghead/tha3/images/README.md
diff --git a/live2d/tha3/images/example.png b/talkinghead/tha3/images/example.png
similarity index 100%
rename from live2d/tha3/images/example.png
rename to talkinghead/tha3/images/example.png
diff --git a/live2d/tha3/images/inital.png b/talkinghead/tha3/images/inital.png
similarity index 100%
rename from live2d/tha3/images/inital.png
rename to talkinghead/tha3/images/inital.png
diff --git a/live2d/tha3/images/input_spec.png b/talkinghead/tha3/images/input_spec.png
similarity index 100%
rename from live2d/tha3/images/input_spec.png
rename to talkinghead/tha3/images/input_spec.png
diff --git a/live2d/tha3/mocap/__init__.py b/talkinghead/tha3/mocap/__init__.py
similarity index 100%
rename from live2d/tha3/mocap/__init__.py
rename to talkinghead/tha3/mocap/__init__.py
diff --git a/live2d/tha3/mocap/ifacialmocap_constants.py b/talkinghead/tha3/mocap/ifacialmocap_constants.py
similarity index 100%
rename from live2d/tha3/mocap/ifacialmocap_constants.py
rename to talkinghead/tha3/mocap/ifacialmocap_constants.py
diff --git a/live2d/tha3/mocap/ifacialmocap_pose.py b/talkinghead/tha3/mocap/ifacialmocap_pose.py
similarity index 100%
rename from live2d/tha3/mocap/ifacialmocap_pose.py
rename to talkinghead/tha3/mocap/ifacialmocap_pose.py
diff --git a/live2d/tha3/mocap/ifacialmocap_pose_converter.py b/talkinghead/tha3/mocap/ifacialmocap_pose_converter.py
similarity index 100%
rename from live2d/tha3/mocap/ifacialmocap_pose_converter.py
rename to talkinghead/tha3/mocap/ifacialmocap_pose_converter.py
diff --git a/live2d/tha3/mocap/ifacialmocap_poser_converter_25.py b/talkinghead/tha3/mocap/ifacialmocap_poser_converter_25.py
similarity index 100%
rename from live2d/tha3/mocap/ifacialmocap_poser_converter_25.py
rename to talkinghead/tha3/mocap/ifacialmocap_poser_converter_25.py
diff --git a/live2d/tha3/mocap/ifacialmocap_v2.py b/talkinghead/tha3/mocap/ifacialmocap_v2.py
similarity index 100%
rename from live2d/tha3/mocap/ifacialmocap_v2.py
rename to talkinghead/tha3/mocap/ifacialmocap_v2.py
diff --git a/live2d/tha3/models/LICENSE.txt b/talkinghead/tha3/models/LICENSE.txt
similarity index 100%
rename from live2d/tha3/models/LICENSE.txt
rename to talkinghead/tha3/models/LICENSE.txt
diff --git a/live2d/tha3/models/placeholder.txt b/talkinghead/tha3/models/placeholder.txt
similarity index 100%
rename from live2d/tha3/models/placeholder.txt
rename to talkinghead/tha3/models/placeholder.txt
diff --git a/live2d/tha3/models/separable_float/editor.pt b/talkinghead/tha3/models/separable_float/editor.pt
similarity index 100%
rename from live2d/tha3/models/separable_float/editor.pt
rename to talkinghead/tha3/models/separable_float/editor.pt
diff --git a/live2d/tha3/models/separable_float/eyebrow_decomposer.pt b/talkinghead/tha3/models/separable_float/eyebrow_decomposer.pt
similarity index 100%
rename from live2d/tha3/models/separable_float/eyebrow_decomposer.pt
rename to talkinghead/tha3/models/separable_float/eyebrow_decomposer.pt
diff --git a/live2d/tha3/models/separable_float/eyebrow_morphing_combiner.pt b/talkinghead/tha3/models/separable_float/eyebrow_morphing_combiner.pt
similarity index 100%
rename from live2d/tha3/models/separable_float/eyebrow_morphing_combiner.pt
rename to talkinghead/tha3/models/separable_float/eyebrow_morphing_combiner.pt
diff --git a/live2d/tha3/models/separable_float/face_morpher.pt b/talkinghead/tha3/models/separable_float/face_morpher.pt
similarity index 100%
rename from live2d/tha3/models/separable_float/face_morpher.pt
rename to talkinghead/tha3/models/separable_float/face_morpher.pt
diff --git a/live2d/tha3/models/separable_float/two_algo_face_body_rotator.pt b/talkinghead/tha3/models/separable_float/two_algo_face_body_rotator.pt
similarity index 100%
rename from live2d/tha3/models/separable_float/two_algo_face_body_rotator.pt
rename to talkinghead/tha3/models/separable_float/two_algo_face_body_rotator.pt
diff --git a/live2d/tha3/module/__init__.py b/talkinghead/tha3/module/__init__.py
similarity index 100%
rename from live2d/tha3/module/__init__.py
rename to talkinghead/tha3/module/__init__.py
diff --git a/live2d/tha3/module/module_factory.py b/talkinghead/tha3/module/module_factory.py
similarity index 100%
rename from live2d/tha3/module/module_factory.py
rename to talkinghead/tha3/module/module_factory.py
diff --git a/live2d/tha3/nn/__init__.py b/talkinghead/tha3/nn/__init__.py
similarity index 100%
rename from live2d/tha3/nn/__init__.py
rename to talkinghead/tha3/nn/__init__.py
diff --git a/live2d/tha3/nn/common/__init__.py b/talkinghead/tha3/nn/common/__init__.py
similarity index 100%
rename from live2d/tha3/nn/common/__init__.py
rename to talkinghead/tha3/nn/common/__init__.py
diff --git a/live2d/tha3/nn/common/conv_block_factory.py b/talkinghead/tha3/nn/common/conv_block_factory.py
similarity index 100%
rename from live2d/tha3/nn/common/conv_block_factory.py
rename to talkinghead/tha3/nn/common/conv_block_factory.py
diff --git a/live2d/tha3/nn/common/poser_args.py b/talkinghead/tha3/nn/common/poser_args.py
similarity index 100%
rename from live2d/tha3/nn/common/poser_args.py
rename to talkinghead/tha3/nn/common/poser_args.py
diff --git a/live2d/tha3/nn/common/poser_encoder_decoder_00.py b/talkinghead/tha3/nn/common/poser_encoder_decoder_00.py
similarity index 100%
rename from live2d/tha3/nn/common/poser_encoder_decoder_00.py
rename to talkinghead/tha3/nn/common/poser_encoder_decoder_00.py
diff --git a/live2d/tha3/nn/common/poser_encoder_decoder_00_separable.py b/talkinghead/tha3/nn/common/poser_encoder_decoder_00_separable.py
similarity index 100%
rename from live2d/tha3/nn/common/poser_encoder_decoder_00_separable.py
rename to talkinghead/tha3/nn/common/poser_encoder_decoder_00_separable.py
diff --git a/live2d/tha3/nn/common/resize_conv_encoder_decoder.py b/talkinghead/tha3/nn/common/resize_conv_encoder_decoder.py
similarity index 100%
rename from live2d/tha3/nn/common/resize_conv_encoder_decoder.py
rename to talkinghead/tha3/nn/common/resize_conv_encoder_decoder.py
diff --git a/live2d/tha3/nn/common/resize_conv_unet.py b/talkinghead/tha3/nn/common/resize_conv_unet.py
similarity index 100%
rename from live2d/tha3/nn/common/resize_conv_unet.py
rename to talkinghead/tha3/nn/common/resize_conv_unet.py
diff --git a/live2d/tha3/nn/conv.py b/talkinghead/tha3/nn/conv.py
similarity index 100%
rename from live2d/tha3/nn/conv.py
rename to talkinghead/tha3/nn/conv.py
diff --git a/live2d/tha3/nn/editor/__init__.py b/talkinghead/tha3/nn/editor/__init__.py
similarity index 100%
rename from live2d/tha3/nn/editor/__init__.py
rename to talkinghead/tha3/nn/editor/__init__.py
diff --git a/live2d/tha3/nn/editor/editor_07.py b/talkinghead/tha3/nn/editor/editor_07.py
similarity index 100%
rename from live2d/tha3/nn/editor/editor_07.py
rename to talkinghead/tha3/nn/editor/editor_07.py
diff --git a/live2d/tha3/nn/eyebrow_decomposer/__init__.py b/talkinghead/tha3/nn/eyebrow_decomposer/__init__.py
similarity index 100%
rename from live2d/tha3/nn/eyebrow_decomposer/__init__.py
rename to talkinghead/tha3/nn/eyebrow_decomposer/__init__.py
diff --git a/live2d/tha3/nn/eyebrow_decomposer/eyebrow_decomposer_00.py b/talkinghead/tha3/nn/eyebrow_decomposer/eyebrow_decomposer_00.py
similarity index 100%
rename from live2d/tha3/nn/eyebrow_decomposer/eyebrow_decomposer_00.py
rename to talkinghead/tha3/nn/eyebrow_decomposer/eyebrow_decomposer_00.py
diff --git a/live2d/tha3/nn/eyebrow_decomposer/eyebrow_decomposer_03.py b/talkinghead/tha3/nn/eyebrow_decomposer/eyebrow_decomposer_03.py
similarity index 100%
rename from live2d/tha3/nn/eyebrow_decomposer/eyebrow_decomposer_03.py
rename to talkinghead/tha3/nn/eyebrow_decomposer/eyebrow_decomposer_03.py
diff --git a/live2d/tha3/nn/eyebrow_morphing_combiner/__init__.py b/talkinghead/tha3/nn/eyebrow_morphing_combiner/__init__.py
similarity index 100%
rename from live2d/tha3/nn/eyebrow_morphing_combiner/__init__.py
rename to talkinghead/tha3/nn/eyebrow_morphing_combiner/__init__.py
diff --git a/live2d/tha3/nn/eyebrow_morphing_combiner/eyebrow_morphing_combiner_00.py b/talkinghead/tha3/nn/eyebrow_morphing_combiner/eyebrow_morphing_combiner_00.py
similarity index 100%
rename from live2d/tha3/nn/eyebrow_morphing_combiner/eyebrow_morphing_combiner_00.py
rename to talkinghead/tha3/nn/eyebrow_morphing_combiner/eyebrow_morphing_combiner_00.py
diff --git a/live2d/tha3/nn/eyebrow_morphing_combiner/eyebrow_morphing_combiner_03.py b/talkinghead/tha3/nn/eyebrow_morphing_combiner/eyebrow_morphing_combiner_03.py
similarity index 100%
rename from live2d/tha3/nn/eyebrow_morphing_combiner/eyebrow_morphing_combiner_03.py
rename to talkinghead/tha3/nn/eyebrow_morphing_combiner/eyebrow_morphing_combiner_03.py
diff --git a/live2d/tha3/nn/face_morpher/__init__.py b/talkinghead/tha3/nn/face_morpher/__init__.py
similarity index 100%
rename from live2d/tha3/nn/face_morpher/__init__.py
rename to talkinghead/tha3/nn/face_morpher/__init__.py
diff --git a/live2d/tha3/nn/face_morpher/face_morpher_08.py b/talkinghead/tha3/nn/face_morpher/face_morpher_08.py
similarity index 100%
rename from live2d/tha3/nn/face_morpher/face_morpher_08.py
rename to talkinghead/tha3/nn/face_morpher/face_morpher_08.py
diff --git a/live2d/tha3/nn/face_morpher/face_morpher_09.py b/talkinghead/tha3/nn/face_morpher/face_morpher_09.py
similarity index 100%
rename from live2d/tha3/nn/face_morpher/face_morpher_09.py
rename to talkinghead/tha3/nn/face_morpher/face_morpher_09.py
diff --git a/live2d/tha3/nn/image_processing_util.py b/talkinghead/tha3/nn/image_processing_util.py
similarity index 100%
rename from live2d/tha3/nn/image_processing_util.py
rename to talkinghead/tha3/nn/image_processing_util.py
diff --git a/live2d/tha3/nn/init_function.py b/talkinghead/tha3/nn/init_function.py
similarity index 100%
rename from live2d/tha3/nn/init_function.py
rename to talkinghead/tha3/nn/init_function.py
diff --git a/live2d/tha3/nn/nonlinearity_factory.py b/talkinghead/tha3/nn/nonlinearity_factory.py
similarity index 100%
rename from live2d/tha3/nn/nonlinearity_factory.py
rename to talkinghead/tha3/nn/nonlinearity_factory.py
diff --git a/live2d/tha3/nn/normalization.py b/talkinghead/tha3/nn/normalization.py
similarity index 100%
rename from live2d/tha3/nn/normalization.py
rename to talkinghead/tha3/nn/normalization.py
diff --git a/live2d/tha3/nn/pass_through.py b/talkinghead/tha3/nn/pass_through.py
similarity index 100%
rename from live2d/tha3/nn/pass_through.py
rename to talkinghead/tha3/nn/pass_through.py
diff --git a/live2d/tha3/nn/resnet_block.py b/talkinghead/tha3/nn/resnet_block.py
similarity index 100%
rename from live2d/tha3/nn/resnet_block.py
rename to talkinghead/tha3/nn/resnet_block.py
diff --git a/live2d/tha3/nn/resnet_block_seperable.py b/talkinghead/tha3/nn/resnet_block_seperable.py
similarity index 100%
rename from live2d/tha3/nn/resnet_block_seperable.py
rename to talkinghead/tha3/nn/resnet_block_seperable.py
diff --git a/live2d/tha3/nn/separable_conv.py b/talkinghead/tha3/nn/separable_conv.py
similarity index 100%
rename from live2d/tha3/nn/separable_conv.py
rename to talkinghead/tha3/nn/separable_conv.py
diff --git a/live2d/tha3/nn/spectral_norm.py b/talkinghead/tha3/nn/spectral_norm.py
similarity index 100%
rename from live2d/tha3/nn/spectral_norm.py
rename to talkinghead/tha3/nn/spectral_norm.py
diff --git a/live2d/tha3/nn/two_algo_body_rotator/__init__.py b/talkinghead/tha3/nn/two_algo_body_rotator/__init__.py
similarity index 100%
rename from live2d/tha3/nn/two_algo_body_rotator/__init__.py
rename to talkinghead/tha3/nn/two_algo_body_rotator/__init__.py
diff --git a/live2d/tha3/nn/two_algo_body_rotator/two_algo_face_body_rotator_05.py b/talkinghead/tha3/nn/two_algo_body_rotator/two_algo_face_body_rotator_05.py
similarity index 100%
rename from live2d/tha3/nn/two_algo_body_rotator/two_algo_face_body_rotator_05.py
rename to talkinghead/tha3/nn/two_algo_body_rotator/two_algo_face_body_rotator_05.py
diff --git a/live2d/tha3/nn/util.py b/talkinghead/tha3/nn/util.py
similarity index 100%
rename from live2d/tha3/nn/util.py
rename to talkinghead/tha3/nn/util.py
diff --git a/live2d/tha3/poser/__init__.py b/talkinghead/tha3/poser/__init__.py
similarity index 100%
rename from live2d/tha3/poser/__init__.py
rename to talkinghead/tha3/poser/__init__.py
diff --git a/live2d/tha3/poser/general_poser_02.py b/talkinghead/tha3/poser/general_poser_02.py
similarity index 100%
rename from live2d/tha3/poser/general_poser_02.py
rename to talkinghead/tha3/poser/general_poser_02.py
diff --git a/live2d/tha3/poser/modes/__init__.py b/talkinghead/tha3/poser/modes/__init__.py
similarity index 100%
rename from live2d/tha3/poser/modes/__init__.py
rename to talkinghead/tha3/poser/modes/__init__.py
diff --git a/live2d/tha3/poser/modes/load_poser.py b/talkinghead/tha3/poser/modes/load_poser.py
similarity index 100%
rename from live2d/tha3/poser/modes/load_poser.py
rename to talkinghead/tha3/poser/modes/load_poser.py
diff --git a/live2d/tha3/poser/modes/pose_parameters.py b/talkinghead/tha3/poser/modes/pose_parameters.py
similarity index 100%
rename from live2d/tha3/poser/modes/pose_parameters.py
rename to talkinghead/tha3/poser/modes/pose_parameters.py
diff --git a/live2d/tha3/poser/modes/separable_float.py b/talkinghead/tha3/poser/modes/separable_float.py
similarity index 98%
rename from live2d/tha3/poser/modes/separable_float.py
rename to talkinghead/tha3/poser/modes/separable_float.py
index b907079..4fd07cc 100644
--- a/live2d/tha3/poser/modes/separable_float.py
+++ b/talkinghead/tha3/poser/modes/separable_float.py
@@ -263,23 +263,23 @@ def create_poser(
if module_file_names is None:
module_file_names = {}
if Network.eyebrow_decomposer.name not in module_file_names:
- dir = "live2d/tha3/models/separable_float"
+ dir = "talkinghead/tha3/models/separable_float"
file_name = dir + "/eyebrow_decomposer.pt"
module_file_names[Network.eyebrow_decomposer.name] = file_name
if Network.eyebrow_morphing_combiner.name not in module_file_names:
- dir = "live2d/tha3/models/separable_float"
+ dir = "talkinghead/tha3/models/separable_float"
file_name = dir + "/eyebrow_morphing_combiner.pt"
module_file_names[Network.eyebrow_morphing_combiner.name] = file_name
if Network.face_morpher.name not in module_file_names:
- dir = "live2d/tha3/models/separable_float"
+ dir = "talkinghead/tha3/models/separable_float"
file_name = dir + "/face_morpher.pt"
module_file_names[Network.face_morpher.name] = file_name
if Network.two_algo_face_body_rotator.name not in module_file_names:
- dir = "live2d/tha3/models/separable_float"
+ dir = "talkinghead/tha3/models/separable_float"
file_name = dir + "/two_algo_face_body_rotator.pt"
module_file_names[Network.two_algo_face_body_rotator.name] = file_name
if Network.editor.name not in module_file_names:
- dir = "live2d/tha3/models/separable_float"
+ dir = "talkinghead/tha3/models/separable_float"
file_name = dir + "/editor.pt"
module_file_names[Network.editor.name] = file_name
diff --git a/live2d/tha3/poser/modes/separable_half.py b/talkinghead/tha3/poser/modes/separable_half.py
similarity index 98%
rename from live2d/tha3/poser/modes/separable_half.py
rename to talkinghead/tha3/poser/modes/separable_half.py
index e2994af..24d29ed 100644
--- a/live2d/tha3/poser/modes/separable_half.py
+++ b/talkinghead/tha3/poser/modes/separable_half.py
@@ -296,23 +296,23 @@ def create_poser(
if module_file_names is None:
module_file_names = {}
if Network.eyebrow_decomposer.name not in module_file_names:
- dir = "live2d/tha3/models/separable_half"
+ dir = "talkinghead/tha3/models/separable_half"
file_name = dir + "/eyebrow_decomposer.pt"
module_file_names[Network.eyebrow_decomposer.name] = file_name
if Network.eyebrow_morphing_combiner.name not in module_file_names:
- dir = "live2d/tha3/models/separable_half"
+ dir = "talkinghead/tha3/models/separable_half"
file_name = dir + "/eyebrow_morphing_combiner.pt"
module_file_names[Network.eyebrow_morphing_combiner.name] = file_name
if Network.face_morpher.name not in module_file_names:
- dir = "live2d/tha3/models/separable_half"
+ dir = "talkinghead/tha3/models/separable_half"
file_name = dir + "/face_morpher.pt"
module_file_names[Network.face_morpher.name] = file_name
if Network.two_algo_face_body_rotator.name not in module_file_names:
- dir = "live2d/tha3/models/separable_half"
+ dir = "talkinghead/tha3/models/separable_half"
file_name = dir + "/two_algo_face_body_rotator.pt"
module_file_names[Network.two_algo_face_body_rotator.name] = file_name
if Network.editor.name not in module_file_names:
- dir = "live2d/tha3/models/separable_half"
+ dir = "talkinghead/tha3/models/separable_half"
file_name = dir + "/editor.pt"
module_file_names[Network.editor.name] = file_name
diff --git a/live2d/tha3/poser/modes/standard_float.py b/talkinghead/tha3/poser/modes/standard_float.py
similarity index 98%
rename from live2d/tha3/poser/modes/standard_float.py
rename to talkinghead/tha3/poser/modes/standard_float.py
index 69ad81b..f75008f 100644
--- a/live2d/tha3/poser/modes/standard_float.py
+++ b/talkinghead/tha3/poser/modes/standard_float.py
@@ -294,23 +294,23 @@ def create_poser(
if module_file_names is None:
module_file_names = {}
if Network.eyebrow_decomposer.name not in module_file_names:
- dir = "live2d/tha3/models/standard_float"
+ dir = "talkinghead/tha3/models/standard_float"
file_name = dir + "/eyebrow_decomposer.pt"
module_file_names[Network.eyebrow_decomposer.name] = file_name
if Network.eyebrow_morphing_combiner.name not in module_file_names:
- dir = "live2d/tha3/models/standard_float"
+ dir = "talkinghead/tha3/models/standard_float"
file_name = dir + "/eyebrow_morphing_combiner.pt"
module_file_names[Network.eyebrow_morphing_combiner.name] = file_name
if Network.face_morpher.name not in module_file_names:
- dir = "live2d/tha3/models/standard_float"
+ dir = "talkinghead/tha3/models/standard_float"
file_name = dir + "/face_morpher.pt"
module_file_names[Network.face_morpher.name] = file_name
if Network.two_algo_face_body_rotator.name not in module_file_names:
- dir = "live2d/tha3/models/standard_float"
+ dir = "talkinghead/tha3/models/standard_float"
file_name = dir + "/two_algo_face_body_rotator.pt"
module_file_names[Network.two_algo_face_body_rotator.name] = file_name
if Network.editor.name not in module_file_names:
- dir = "live2d/tha3/models/standard_float"
+ dir = "talkinghead/tha3/models/standard_float"
file_name = dir + "/editor.pt"
module_file_names[Network.editor.name] = file_name
diff --git a/live2d/tha3/poser/modes/standard_half.py b/talkinghead/tha3/poser/modes/standard_half.py
similarity index 98%
rename from live2d/tha3/poser/modes/standard_half.py
rename to talkinghead/tha3/poser/modes/standard_half.py
index 611b384..5d28bc3 100644
--- a/live2d/tha3/poser/modes/standard_half.py
+++ b/talkinghead/tha3/poser/modes/standard_half.py
@@ -294,23 +294,23 @@ def create_poser(
if module_file_names is None:
module_file_names = {}
if Network.eyebrow_decomposer.name not in module_file_names:
- dir = "live2d/tha3/models/standard_half"
+ dir = "talkinghead/tha3/models/standard_half"
file_name = dir + "/eyebrow_decomposer.pt"
module_file_names[Network.eyebrow_decomposer.name] = file_name
if Network.eyebrow_morphing_combiner.name not in module_file_names:
- dir = "live2d/tha3/models/standard_half"
+ dir = "talkinghead/tha3/models/standard_half"
file_name = dir + "/eyebrow_morphing_combiner.pt"
module_file_names[Network.eyebrow_morphing_combiner.name] = file_name
if Network.face_morpher.name not in module_file_names:
- dir = "live2d/tha3/models/standard_half"
+ dir = "talkinghead/tha3/models/standard_half"
file_name = dir + "/face_morpher.pt"
module_file_names[Network.face_morpher.name] = file_name
if Network.two_algo_face_body_rotator.name not in module_file_names:
- dir = "live2d/tha3/models/standard_half"
+ dir = "talkinghead/tha3/models/standard_half"
file_name = dir + "/two_algo_face_body_rotator.pt"
module_file_names[Network.two_algo_face_body_rotator.name] = file_name
if Network.editor.name not in module_file_names:
- dir = "live2d/tha3/models/standard_half"
+ dir = "talkinghead/tha3/models/standard_half"
file_name = dir + "/editor.pt"
module_file_names[Network.editor.name] = file_name
diff --git a/server.py b/server.py
index 6aadb4a..77904ab 100644
--- a/server.py
+++ b/server.py
@@ -86,7 +86,7 @@ parser.add_argument('--chroma-persist', help="ChromaDB persistence", default=Tru
parser.add_argument(
"--secure", action="store_true", help="Enforces the use of an API key"
)
-parser.add_argument("--live2d-gpu", action="store_true", help="Run the live2d animation on the GPU (CPU is default)")
+parser.add_argument("--talkinghead-gpu", action="store_true", help="Run the talkinghead animation on the GPU (CPU is default)")
parser.add_argument("--coqui-gpu", action="store_false", help="Run the voice models on the GPU (CPU is default)")
parser.add_argument("--coqui-model", help="Load a custom Coqui TTS model")
parser.add_argument("--stt-vosk-model-path", help="Load a custom vosk speech-to-text model")
@@ -175,27 +175,27 @@ if not torch.cuda.is_available() and not args.cpu:
print(f"{Fore.GREEN}{Style.BRIGHT}Using torch device: {device_string}{Style.RESET_ALL}")
-if "live2d" in modules:
+if "talkinghead" in modules:
import sys
import threading
- mode = "cuda" if args.live2d_gpu else "cpu"
- print("Initializing live2d pipeline in " + mode + " mode....")
- live2d_path = os.path.abspath(os.path.join(os.getcwd(), "live2d"))
- sys.path.append(live2d_path) # Add the path to the 'tha3' module to the sys.path list
+ mode = "cuda" if args.talkinghead_gpu else "cpu"
+ print("Initializing talkinghead pipeline in " + mode + " mode....")
+ talkinghead_path = os.path.abspath(os.path.join(os.getcwd(), "talkinghead"))
+ sys.path.append(talkinghead_path) # Add the path to the 'tha3' module to the sys.path list
try:
- import live2d.tha3.app.app as live2d
- from live2d import *
- def launch_live2d_gui():
- live2d.launch_gui(mode, "separable_float")
+ import talkinghead.tha3.app.app as talkinghead
+ from talkinghead import *
+ def launch_talkinghead_gui():
+ talkinghead.launch_gui(mode, "separable_float")
#choices=['standard_float', 'separable_float', 'standard_half', 'separable_half'],
#choices='The device to use for PyTorch ("cuda" for GPU, "cpu" for CPU).'
- live2d_thread = threading.Thread(target=launch_live2d_gui)
- live2d_thread.daemon = True # Set the thread as a daemon thread
- live2d_thread.start()
+ talkinghead_thread = threading.Thread(target=launch_talkinghead_gui)
+ talkinghead_thread.daemon = True # Set the thread as a daemon thread
+ talkinghead_thread.start()
except ModuleNotFoundError:
- print("Error: Could not import the 'live2d' module.")
+ print("Error: Could not import the 'talkinghead' module.")
if "caption" in modules:
print("Initializing an image captioning model...")
@@ -625,8 +625,8 @@ def api_classify():
classification = classify_text(data["text"])
print("Classification output:", classification, sep="\n")
gc.collect()
- if "live2d" in modules: #send emotion to live2d
- live2d.setEmotion(classification)
+ if "talkinghead" in modules: #send emotion to talkinghead
+ talkinghead.setEmotion(classification)
return jsonify({"classification": classification})
@@ -635,31 +635,31 @@ def api_classify():
def api_classify_labels():
classification = classify_text("")
labels = [x["label"] for x in classification]
- if "live2d" in modules:
- labels.append('live2d') # Add 'live2d' to the labels list
+ if "talkinghead" in modules:
+ labels.append('talkinghead') # Add 'talkinghead' to the labels list
return jsonify({"labels": labels})
-@app.route("/api/live2d/load", methods=["POST"])
+@app.route("/api/talkinghead/load", methods=["POST"])
def live_load():
file = request.files['file']
- # convert stream to bytes and pass to live2d_load
- return live2d.live2d_load_file(file.stream)
+ # convert stream to bytes and pass to talkinghead_load
+ return talkinghead.talkinghead_load_file(file.stream)
-@app.route('/api/live2d/unload')
+@app.route('/api/talkinghead/unload')
def live_unload():
- return live2d.unload()
+ return talkinghead.unload()
-@app.route('/api/live2d/start_talking')
+@app.route('/api/talkinghead/start_talking')
def start_talking():
- return live2d.start_talking()
+ return talkinghead.start_talking()
-@app.route('/api/live2d/stop_talking')
+@app.route('/api/talkinghead/stop_talking')
def stop_talking():
- return live2d.stop_talking()
+ return talkinghead.stop_talking()
-@app.route('/api/live2d/result_feed')
+@app.route('/api/talkinghead/result_feed')
def result_feed():
- return live2d.result_feed()
+ return talkinghead.result_feed()
@app.route("/api/coqui-tts/load", methods=["GET"])
@require_module("coqui-tts")
diff --git a/live2d/tha3/poser/poser.py b/talkinghead/tha3/poser/poser.py
similarity index 100%
rename from live2d/tha3/poser/poser.py
rename to talkinghead/tha3/poser/poser.py
diff --git a/live2d/tha3/util.py b/talkinghead/tha3/util.py
similarity index 100%
rename from live2d/tha3/util.py
rename to talkinghead/tha3/util.py